LoadGridU Proto

GridMsg Proto SYSCALL GridHandle:dword,Request:dword,Parameters:vararg
	; if an error occurs, ecx will contain the error number, else zero
	
gmsg macro Handle:req,Parameters:vararg
	invoke GridMsg,Handle,Parameters
	or ecx,ecx	;; test for error
EndM

gAll = -1     ; command refers to all data columns  or rows (not headers)
gActive = -2  ; command refers to active column or row

;Requests
		;  all request for information will be returned in eax,
		;     if a second value is requested, it will be in edx

		; grid requests
GetAutoPaint           equ 01
SetAutoPaint           equ 02  ; ,True/False
GetDrawBorder          equ 03
SetDrawBorder          equ 04  ; ,True/False
GetHorzLinesColor      equ 05
SetHorzLinesColor      equ 06  ; ,Color
GetVertLinesColor      equ 07
SetVertLinesColor      equ 08  ; ,Color
GetHorzLinesVisible    equ 09
SetHorzLinesVisible    equ 10  ; ,True/False
GetVertLinesVisible    equ 11
SetVertLinesVisible    equ 12  ; ,True/False
GetPreventGridResize   equ 13
SetPreventGridResize   equ 14
SetGridSize            equ 15  ; ,Cols,Rows
GetGridSize            equ 16  ; returns Rows in edx, Cols in eax
		; row and column requests
GetColWidth            equ 21  ; ,Col
SetColWidth            equ 22  ; ,Col,Width
GetRowHeight           equ 23  ; ,Row
SetRowHeight           equ 24  ; ,Row,Height
GetColVisible          equ 25  ; ,Col
SetColVisible          equ 26  ; ,Col,True/False
GetRowVisible          equ 27  ; ,Row
SetRowVisible          equ 28  ; ,Row,True/False
GetPreventColResize    equ 29
SetPreventColResize    equ 30
GetPreventRowResize    equ 31
SetPreventRowResize    equ 32
InsertRowAfter         equ 33  ; ,Row number
RemoveRow              equ 34  ; ,Row number
InsertColAfter         equ 35  ; ,Col number
RemoveCol              equ 36  ; ,Col number
MoveRows               equ 37  ; ,FirstRow,NumRows,NewRow
MoveCols               equ 38  ; ,FirstCol,NumCols,NewCol
SortByCol              equ 39  ; ,Col to sort by
		; cell requests
GetActiveCell          equ 41  ; Returns col in eax, row in edx
SetActiveCell          equ 42  ; ,Col,Row
SetCellText            equ 43  ; ,Col,Row,Address of text
GetCellText            equ 44  ; ,Col,Row,Buffer,MaxLength
GetCellBackColor       equ 45  ; ,Col,Row
GetCellForeColor       equ 46  ; ,Col,Row
SetCellBackColor       equ 47  ; ,Col,Row,Color
SetCellForeColor       equ 48  ; ,Col,Row,Color
GetCellColors          equ 49  ; ,Col,Row    Returns edx=fore, eax=back color
SetCellColors          equ 50  ; ,Col,Row,Forecolor,Backcolor
GetCellTextAlignment   equ 51  ; ,Col,Row
SetCellTextAlignment   equ 52  ; ,Col,Row,DT_LEFT/DT_CENTER/DT_RIGHT
GetCell3D              equ 53  ; ,Col,Row
SetCell3D              equ 54  ; ,Col,Row,True/False
GetCellReadOnly        equ 55  ; ,Col,Row
SetCellReadOnly        equ 56  ; ,Col,Row,True/False
GetCellMultiLine       equ 57  ; ,Col,Row
SetCellMultiLine       equ 58  ; ,Col,Row,True/False
GetCellFontHandle      equ 59  ; ,Col,Row
SetCellFontHandle      equ 60  ; ,Col,Row,FontHandle
		; scroll bar requests
GetScrollbarArrowSize  equ 71
SetScrollbarArrowSize  equ 72  ; ,New size
GetVertScrollBarWidth  equ 73
SetVertScrollBarWidth  equ 74  ; ,New width
GetHorzScrollBarHeight equ 75
SetHorzScrollBarHeight equ 76  ; ,New height
		; defaults for new rows/columns
SetDefFontHandle       equ 82  ; ,FontHandle
GetDefColWidth         equ 83
SetDefColWidth         equ 84  ; ,Col width
GetDefRowHeight        equ 85
SetDefRowHeight        equ 86  ; ,Row Height
GetDefCellBackColor    equ 87
SetDefCellBackColor    equ 88  ; ,Color
GetDefCellForeColor    equ 89
SetDefCellForeColor    equ 90  ; ,Color
GetDefCellTextAlign    equ 91
SetDefCellTextAlign    equ 92  ; ,DT_LEFT/DT_CENTER/DT_RIGHT
GetDefCellDraw3D       equ 93
SetDefCellDraw3D       equ 94  ; ,True/False
GetDefCellReadOnly     equ 95
SetDefCellReadOnly     equ 96  ; ,True/False
GetDefCellMultiLine    equ 97
SetDefCellMultiLine    equ 98  ; ,True/False
                                                                       
		; Messages/Events
	; The grid sends WM_NOTIFY messages to it's parent.
	;   all events will have grid ID in wParam, and
	;   will have address of a GridInfo structure in lParam
	;   user should return TRUE in eax to cancel where appropriate,
	;    otherwise, fill in any required values in the structure.
	
GridInfo struct
    hwndFrom  dd ? ; handle of grid sending the message
    idFrom    dd ? ; id of the grid sending the message
    code      dd ? ; one of the codes below
    row       dd ? ; the row number if appropriate 
    col       dd ? ; the column number if appropriate
    buffer    dd ? ; the address of text
    val1      dd ? ; first value if appropriate, else garbage
    val2      dd ? ; second value if appropriate
    val3      dd ? ; third value if appropriate
    cancel    dd ? ; set to TRUE to cancel the action when indicated
GridInfo EndS
 ; where code is one of the following:	
GotFocus               equ 101 ; event notification only
LostFocus              equ 102 ; event notification only
CellClick              equ 103 ; event notification only
BeforeActiveCellChange equ 104 ; new .row, .col, set cancel to prevent change
ActiveCellChanged      equ 105 ; new .row, .col
ColWidthChange         equ 106 ; .col valid, val1=new width
RowHeightChange        equ 107 ; .row valid, val1=new height

BeforeEditCell         equ 111 ; set .cancel TRUE to prevent editing
EditingCell			   equ 112 
CellTextChange         equ 113 ; .buffer=NewText
KeyPress               equ 114 ; KeyAscii, Cancel
KeyDown                equ 115 ; KeyCode, Shift
BeforeExitEditCell     equ 116 ; Proposed new text in .buffer
                                       ;  replace .buffer with desired text
                                       ;  and/or set cancel TRUE to prevent exiting edit
MouseEvent             equ 117 ; val1 = uMsg (eg. WM_LBUTTONDOWN,WM_MOUSEMOVE, etc.)
							   ; val2 = wParam
							   ; val3 = lParam 
GridError              equ 200 ; an attempted action caused an error,
                                       ;  error code is in .val1
; Error Codes-
;   1 A system error occured. error number is in .val1
;   2 The grid needs at least 1 row.  Occurs when you try to delete all the data rows
;   3 The grid needs at least 1 column.
;   4 GridMsg called with unknown grid handle
;   5 GridMsg called with unknown request
;   6 No Active Cell currently selected
        